==> seedsui-react-2.6.2.tgz: package/es/Group/Group.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';

var Group = (_temp = _class = function (_Component) {
  _inherits(Group, _Component);

  function Group(props) {
    _classCallCheck(this, Group);

    var _this = _possibleConstructorReturn(this, _Component.call(this, props));

    _this.onClick = function (e) {
      if (_this.props.onClick) _this.props.onClick(Object.getArgs(e, _this.props.args));
    };

    return _this;
  }

  Group.prototype.render = function render() {
    var _this2 = this;

    var _props = this.props,
        args = _props.args,
        children = _props.children,
        style = _props.style,
        className = _props.className,
        onClick = _props.onClick,
        others = _objectWithoutProperties(_props, ['args', 'children', 'style', 'className', 'onClick']);

    return React.createElement(
      'div',
      _extends({ ref: function ref(el) {
          _this2.$el = el;
        }, className: 'group' + (className ? ' ' + className : ''), style: style, onClick: this.onClick }, others),
      children
    );
  };

  return Group;
}(Component), _class.defaultProps = {
  className: 'border-tb'
}, _temp);
export { Group as default };
Group.propTypes = process.env.NODE_ENV !== "production" ? {
  args: PropTypes.any,

  style: PropTypes.object,
  className: PropTypes.string,
  children: PropTypes.node,
  onClick: PropTypes.func
} : {};

==> seedsui-react-2.7.9.tgz: package/es/Group/Group.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';

var Group = (_temp = _class = function (_Component) {
  _inherits(Group, _Component);

  function Group(props) {
    _classCallCheck(this, Group);

    return _possibleConstructorReturn(this, _Component.call(this, props));
  }

  Group.prototype.render = function render() {
    var _this2 = this;

    var _props = this.props,
        children = _props.children,
        others = _objectWithoutProperties(_props, ['children']);

    return React.createElement(
      'div',
      _extends({ ref: function ref(el) {
          _this2.$el = el;
        } }, others, { className: 'group' + (others.className ? ' ' + others.className : '') }),
      children
    );
  };

  return Group;
}(Component), _class.defaultProps = {
  className: 'border-tb'
}, _temp);
export { Group as default };
Group.propTypes = process.env.NODE_ENV !== "production" ? {
  children: PropTypes.node
} : {};
